"""
Auralis Cloud Worker - Distributed AI Compute Platform
"""

__version__ = "0.2.3"
__author__ = "Aman Satyawani"

from .cli import main, AuralisWorker

__all__ = ["main", "AuralisWorker", "__version__"]
